@@ -3,4 +3,4 @@ logging.getLogger(__name__).addHandler(logging.NullHandler())
 
 name = "fritzprofiles"
 
-from .fritzprofiles import FritzProfileSwitch
+from .fritzprofiles import FritzProfileSwitch, get_all_profiles
